==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/main/mainwindow.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "application.h"
#include "mainwindow.h"
#include "audiolevelswidget.h"
#include "playerwidget.h"
#include "lineswidget.h"
#include "currentlinewidget.h"

#include <qlayout.h>
#include <qsplitter.h>

#include <kstatusbar.h>

using namespace SubtitleComposer;

MainWindow::MainWindow():
	KMainWindow( 0 )
{
	actionCollection()->setHighlightingEnabled( true );

	QSplitter* splitter = new QSplitter( this );
	splitter->setOrientation( Qt::Vertical );
	splitter->setMargin( 5 );
	splitter->setFrameShape( QFrame::NoFrame );

	m_audiolevelsWidget = new AudioLevelsWidget( splitter );
	m_audiolevelsWidget->hide();

	m_playerWidget = new PlayerWidget( splitter );

	QWidget* subtitleWidget = new QWidget( splitter );

	m_linesWidget = new LinesWidget( subtitleWidget );
	m_linesWidget->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );

	m_curLineWidget = new CurrentLineWidget( subtitleWidget );

	QVBoxLayout* subtitleWidgetLayout = new QVBoxLayout( subtitleWidget );
	subtitleWidgetLayout->setMargin( 0 );
	subtitleWidgetLayout->setSpacing( 5 );
	subtitleWidgetLayout->add( m_linesWidget );
	subtitleWidgetLayout->add( m_curLineWidget );

	splitter->setCollapsible( subtitleWidget, false );

	QValueList<int> heights;
	heights << 100 << 200 << 500;
	splitter->setSizes( heights );

	setCentralWidget( splitter ); // tell the KMainWindow that this is indeed the main widget
	statusBar()->show(); // a status bar
	toolBar()->show(); // and a tool bar

	connect( actionCollection(), SIGNAL(actionStatusText(const QString&)), statusBar(), SLOT( message(const QString&) ) );
	connect( actionCollection(), SIGNAL(clearStatusText()), statusBar(), SLOT(clear()) );
}


MainWindow::~MainWindow()
{
}

void MainWindow::loadConfig()
{
}

void MainWindow::saveConfig()
{
}

void MainWindow::setSubtitle( Subtitle* /*subtitle*/ )
{
}

bool MainWindow::queryClose()
{
	if ( ! app()->closeSubtitle() )
		return false;

	app()->saveConfig();
	return true;
}

#include "mainwindow.moc"

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/main/mainwindow.cpp <==
/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "application.h"
#include "mainwindow.h"
#include "audiolevelswidget.h"
#include "playerwidget.h"
#include "lineswidget.h"
#include "currentlinewidget.h"
#include <player.h>

#include <qlayout.h>
#include <qsplitter.h>

#include <kstatusbar.h>

using namespace SubtitleComposer;

MainWindow::MainWindow():
	KMainWindow( 0 )
{
	actionCollection()->setHighlightingEnabled( true );

	QSplitter* splitter = new QSplitter( this );
	splitter->setOrientation( Qt::Vertical );
	splitter->setMargin( 5 );
	splitter->setFrameShape( QFrame::NoFrame );

	m_audiolevelsWidget = new AudioLevelsWidget( splitter );
	m_audiolevelsWidget->hide();

	m_playerWidget = new PlayerWidget( splitter );

	QWidget* subtitleWidget = new QWidget( splitter );

	m_linesWidget = new LinesWidget( subtitleWidget );
	m_linesWidget->setSizePolicy( QSizePolicy::Expanding, QSizePolicy::Expanding );

	m_curLineWidget = new CurrentLineWidget( subtitleWidget );

	QVBoxLayout* subtitleWidgetLayout = new QVBoxLayout( subtitleWidget );
	subtitleWidgetLayout->setMargin( 0 );
	subtitleWidgetLayout->setSpacing( 5 );
	subtitleWidgetLayout->addWidget( m_linesWidget, 2 );
	subtitleWidgetLayout->addWidget( m_curLineWidget, 0 );

	splitter->setCollapsible( subtitleWidget, false );

	QValueList<int> heights;
	heights << 100 << 200 << 500;
	splitter->setSizes( heights );

	setCentralWidget( splitter ); // tell the KMainWindow that this is indeed the main widget
	statusBar()->show(); // a status bar
	toolBar()->show(); // and a tool bar

	connect( actionCollection(), SIGNAL(actionStatusText(const QString&)), statusBar(), SLOT( message(const QString&) ) );
	connect( actionCollection(), SIGNAL(clearStatusText()), statusBar(), SLOT(clear()) );
}


MainWindow::~MainWindow()
{
	app()->saveConfig();

	Player* player = Player::instance();

	// We must disconnect the player when closing down, otherwise signal handlers
	// could be called with the some object destroyed, crashing the application
	disconnect( player, 0, 0, 0 );

	player->setApplicationClosingDown();
}

void MainWindow::loadConfig()
{
}

void MainWindow::saveConfig()
{
}

void MainWindow::setSubtitle( Subtitle* /*subtitle*/ )
{
}

bool MainWindow::queryClose()
{
	return app()->closeSubtitle();
}

#include "mainwindow.moc"
